#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 presburger
version:              1.3.1
visibility:           public
id:                   presburger-1.3.1-JNAPePGP3TPFeA1OK4cQ7Z
key:                  presburger-1.3.1-JNAPePGP3TPFeA1OK4cQ7Z
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
homepage:             http://github.com/yav/presburger
synopsis:             A decision procedure for quantifier-free linear arithmetic.
description:
    The decision procedure is based on the algorithm used in
    CVC4, which is itself based on the Omega test.

category:             Algorithms
abi:                  667f65ed3a9c3960295915ab6420cfbd
exposed:              True
exposed-modules:      Data.Integer.SAT
import-dirs:          /usr/lib/ghc-8.10.5/site-local/presburger-1.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/presburger-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/presburger-1.3.1
hs-libraries:         HSpresburger-1.3.1-JNAPePGP3TPFeA1OK4cQ7Z
depends:              base-4.14.2.0 containers-0.6.4.1 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-presburger/html/presburger.haddock
haddock-html:         /usr/share/doc/haskell-presburger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

